==> seedsui-react-5.8.81.tgz: package/lib/Location/Main/Choose/index.js <==
import React, { forwardRef, useImperativeHandle, useRef } from 'react';

// 内库使用
import Map from "./../../../Map";

// 测试使用
// import { Map } from 'seedsui-react'

var APILoader = Map.APILoader,
  MapChoose = Map.MapChoose;

// 地图位置选择
var LocationChoose = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var config = _ref.config,
    readOnly = _ref.readOnly,
    autoLocation = _ref.autoLocation,
    getLocation = _ref.getLocation,
    getAddress = _ref.getAddress,
    value = _ref.value,
    _onChange = _ref.onChange,
    footerRender = _ref.footerRender;
  // 根节点
  var mapRef = useRef(null);
  useImperativeHandle(ref, function () {
    return mapRef.current;
  });
  console.log('config:', value, config, window.APILoaderConfig);
  return /*#__PURE__*/React.createElement(APILoader, {
    config: config || window.APILoaderConfig,
    onSuccess: function onSuccess() {
      console.log('地图加载成功');
    },
    onError: function onError(error) {
      console.log('地图加载失败', error);
      return /*#__PURE__*/React.createElement("div", {
        className: "map-result"
      }, /*#__PURE__*/React.createElement("div", {
        className: "map-result-title"
      }, error.errMsg));
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      position: 'relative',
      width: '100%',
      height: '500px'
    }
  }, /*#__PURE__*/React.createElement(MapChoose, {
    ref: mapRef,
    readOnly: readOnly,
    autoLocation: autoLocation,
    getLocation: getLocation,
    getAddress: getAddress,
    value: value,
    onChange: function onChange(newValue) {
      console.log('修改:', newValue);
      debugger;
      _onChange && _onChange(newValue);
    }
  })));
});
export default LocationChoose;

==> seedsui-react-5.8.90.tgz: package/lib/Location/Main/Choose/index.js <==
import React, { forwardRef, useImperativeHandle, useRef } from 'react';

// 内库使用
import Map from "./../../../Map";

// 测试使用
// import { Map } from 'seedsui-react'

var APILoader = Map.APILoader,
  MapChoose = Map.MapChoose;

// 地图位置选择
var LocationChoose = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var readOnly = _ref.readOnly,
    config = _ref.config,
    zoom = _ref.zoom,
    autoLocation = _ref.autoLocation,
    getLocation = _ref.getLocation,
    getAddress = _ref.getAddress,
    value = _ref.value,
    _onChange = _ref.onChange;
  // 根节点
  var mapRef = useRef(null);
  useImperativeHandle(ref, function () {
    return mapRef.current;
  });
  return /*#__PURE__*/React.createElement(APILoader, {
    config: config || window.APILoaderConfig,
    onSuccess: function onSuccess() {
      console.log('地图加载成功');
    },
    onError: function onError(error) {
      console.log('地图加载失败', error);
      return /*#__PURE__*/React.createElement("div", {
        className: "map-result"
      }, /*#__PURE__*/React.createElement("div", {
        className: "map-result-title"
      }, error.errMsg));
    }
  }, /*#__PURE__*/React.createElement(MapChoose, {
    ref: mapRef,
    readOnly: readOnly,
    zoom: zoom,
    autoLocation: autoLocation,
    getLocation: getLocation,
    getAddress: getAddress,
    value: value,
    onChange: function onChange(newValue) {
      console.log('地址选点:', newValue);
      _onChange && _onChange(newValue);
    }
  }));
});
export default LocationChoose;
